==> dde-clipboard_6.1.14.tar.xz: BUILD/translations/dde-clipboard_el.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="el" version="2.1">
<context>
    <name>ClipboardItem</name>
    <message>
        <location filename="../dock-clipboard-plugin/clipboarditem.cpp" line="34"/>
        <source>Clipboard</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../dock-clipboard-plugin/clipboarditem.cpp" line="65"/>
        <source>Open</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ClipboardPlugin</name>
    <message>
        <location filename="../dock-clipboard-plugin/clipboardplugin.cpp" line="43"/>
        <source>Clipboard</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ItemData</name>
    <message>
        <location filename="../dde-clipboard/itemdata.cpp" line="128"/>
        <source>Picture</source>
        <translation>Εικόνα</translation>
    </message>
    <message>
        <location filename="../dde-clipboard/itemdata.cpp" line="130"/>
        <source>Text</source>
        <translation>Κείμενο</translation>
    </message>
    <message>
        <location filename="../dde-clipboard/itemdata.cpp" line="132"/>
        <source>File</source>
        <translation>Αρχείο</translation>
    </message>
    <message>
        <location filename="../dde-clipboard/itemdata.cpp" line="144"/>
        <source>%1 characters</source>
        <translation>%1 χαρακτήρες</translation>
    </message>
</context>
<context>
    <name>ItemWidget</name>
    <message>
        <location filename="../dde-clipboard/itemwidget.cpp" line="369"/>
        <source>%1 files (%2...)</source>
        <translation>%1 αρχεία (%2...)</translation>
    </message>
    <message>
        <location filename="../dde-clipboard/itemwidget.cpp" line="420"/>
        <location filename="../dde-clipboard/itemwidget.cpp" line="609"/>
        <source>(File deleted)</source>
        <translation>(Το αρχείο διαγράφηκε)</translation>
    </message>
    <message>
        <location filename="../dde-clipboard/itemwidget.cpp" line="443"/>
        <source>Yesterday</source>
        <translation>Χθες</translation>
    </message>
    <message>
        <location filename="../dde-clipboard/itemwidget.cpp" line="449"/>
        <source>Just now</source>
        <translation>Μόλις τώρα</translation>
    </message>
    <message>
        <location filename="../dde-clipboard/itemwidget.cpp" line="451"/>
        <source>1 minute ago</source>
        <translation>1 λεπτό πριν</translation>
    </message>
    <message>
        <location filename="../dde-clipboard/itemwidget.cpp" line="453"/>
        <source>%1 minutes ago</source>
        <translation>%1 λεπτά πριν</translation>
    </message>
    <message>
        <location filename="../dde-clipboard/itemwidget.cpp" line="455"/>
        <source>1 hour ago</source>
        <translation>1 ώρα πριν</translation>
    </message>
    <message>
        <location filename="../dde-clipboard/itemwidget.cpp" line="457"/>
        <source>%1 hours ago</source>
        <translation>%1 ώρες πριν</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../dde-clipboard/mainwindow.cpp" line="208"/>
        <source>Clipboard</source>
        <translation>Πρόχειρο</translation>
    </message>
    <message>
        <location filename="../dde-clipboard/mainwindow.cpp" line="211"/>
        <source>Clear all</source>
        <translation>Εκκαθάριση όλων</translation>
    </message>
</context>
</TS>

==> dde-clipboard_6.1.16.tar.xz: BUILD/translations/dde-clipboard_el.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="el">
<context>
    <name>ClipboardItem</name>
    <message>
        <location filename="../dock-clipboard-plugin/clipboarditem.cpp" line="33"/>
        <source>Clipboard</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../dock-clipboard-plugin/clipboarditem.cpp" line="64"/>
        <source>Open</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ClipboardPlugin</name>
    <message>
        <location filename="../dock-clipboard-plugin/clipboardplugin.cpp" line="44"/>
        <source>Clipboard</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ItemData</name>
    <message>
        <location filename="../dde-clipboard/itemdata.cpp" line="130"/>
        <source>Picture</source>
        <translation>Εικόνα</translation>
    </message>
    <message>
        <location filename="../dde-clipboard/itemdata.cpp" line="132"/>
        <source>Text</source>
        <translation>Κείμενο</translation>
    </message>
    <message>
        <location filename="../dde-clipboard/itemdata.cpp" line="134"/>
        <source>File</source>
        <translation>Αρχείο</translation>
    </message>
    <message>
        <location filename="../dde-clipboard/itemdata.cpp" line="146"/>
        <source>%1 characters</source>
        <translation>%1 χαρακτήρες</translation>
    </message>
</context>
<context>
    <name>ItemWidget</name>
    <message>
        <location filename="../dde-clipboard/itemwidget.cpp" line="369"/>
        <source>%1 files (%2...)</source>
        <translation>%1 αρχεία (%2...)</translation>
    </message>
    <message>
        <location filename="../dde-clipboard/itemwidget.cpp" line="420"/>
        <location filename="../dde-clipboard/itemwidget.cpp" line="609"/>
        <source>(File deleted)</source>
        <translation>(Το αρχείο διαγράφηκε)</translation>
    </message>
    <message>
        <location filename="../dde-clipboard/itemwidget.cpp" line="443"/>
        <source>Yesterday</source>
        <translation>Χθες</translation>
    </message>
    <message>
        <location filename="../dde-clipboard/itemwidget.cpp" line="449"/>
        <source>Just now</source>
        <translation>Μόλις τώρα</translation>
    </message>
    <message>
        <location filename="../dde-clipboard/itemwidget.cpp" line="451"/>
        <source>1 minute ago</source>
        <translation>1 λεπτό πριν</translation>
    </message>
    <message>
        <location filename="../dde-clipboard/itemwidget.cpp" line="453"/>
        <source>%1 minutes ago</source>
        <translation>%1 λεπτά πριν</translation>
    </message>
    <message>
        <location filename="../dde-clipboard/itemwidget.cpp" line="455"/>
        <source>1 hour ago</source>
        <translation>1 ώρα πριν</translation>
    </message>
    <message>
        <location filename="../dde-clipboard/itemwidget.cpp" line="457"/>
        <source>%1 hours ago</source>
        <translation>%1 ώρες πριν</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../dde-clipboard/mainwindow.cpp" line="301"/>
        <source>Clipboard</source>
        <translation>Πρόχειρο</translation>
    </message>
    <message>
        <location filename="../dde-clipboard/mainwindow.cpp" line="304"/>
        <source>Clear all</source>
        <translation>Εκκαθάριση όλων</translation>
    </message>
    <message>
        <location filename="../dde-clipboard/mainwindow.cpp" line="329"/>
        <source>Copy the content to clipboard</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
